#define F_CPU 12000000
#define CMD_GET 1
#include "usbdrv/usbdrv.h"
#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>
#include <avr/eeprom.h>
#include <avr/wdt.h>

#include "usbdrv/oddebug.h"
#include <util/delay.h>
struct {
	unsigned gakt:1;
	unsigned l1akt:1;
	unsigned l2akt:1;
	unsigned l1zeit:8;
	unsigned l2zeit:8;
	unsigned gzeit:16;
} ram;
USB_PUBLIC uchar usbFunctionSetup(uchar data[8])
{
	usbRequest_t *rq = (void *)data;   // cast to structured data for parsing
	static uchar replyBuf[5];
    switch(rq->bRequest){
    
	case CMD_GET:
		replyBuf[0] = (1<<0)|(ram.gakt<<1)|(ram.l1akt<<2)|(ram.l2akt<<3); //1. Ping , 2.gakt ,3. l1akt,4. l2akt
		replyBuf[1] = ram.l1zeit;		// l1zeit
		replyBuf[2] = ram.l2zeit;		// l2zeit
		replyBuf[3] = (ram.gzeit>>8);	// 9 - 16.Bit von gzeit
		replyBuf[4] = ram.gzeit;		//1-8.Bit von gzeit
		return 5;

    }
    return 0;

}
int main(void)
{
	TCCR1B |= (1<<CS10)|(1<<WGM12);
	GIMSK |= (1<<PCIE);
	PCMSK |= (1<<PCINT0)|(1<<PCINT1);
	TIMSK |= (1<<OCIE1A);
	OCR1A = 11999;
	uchar   i;
    wdt_enable(WDTO_1S);
	odDebugInit();
	sei();
	usbDeviceDisconnect();  
    i = 0;
    while(--i){    
        wdt_reset();
        _delay_ms(2);
    }
    usbDeviceConnect();
	usbInit();
    sei();
	
    for(;;){                
        wdt_reset();
        usbPoll();
    }
    return 0;
}

ISR(TIMER1_COMPA_vect)
{
	if(ram.gakt == 1)
	{
		if(ram.gzeit == 0xFFFF)
		{
			ram.gzeit = 0;
		}
		else ram.gzeit++;
	}
	if(ram.l1akt == 1)
	{
		if(ram.l1zeit == 0xFF)
		{
			ram.l1zeit = 0;
		}
		else ram.l1zeit++;
	}
	if(ram.l2akt == 1)
	{
		if(ram.l2zeit == 0xFF)
		{
			ram.l2zeit = 0;
		}
		else ram.l2zeit++;
	}
}
ISR(PCINT_vect)
{
	if(!(PINB & (1<<PINB0)) && ram.l1akt != 1 && ram.gakt != 1)
	{
		ram.gzeit = 0;
		ram.l1zeit = 0;
		ram.l2zeit = 0;
		ram.gakt = 1;
		ram.l1akt = 1;
	}
	if((PINB & (1<<PINB0)) && ram.l1akt == 1)
	{
		ram.l1akt = 0;
	}
	if(!(PINB & (1<<PINB1)) && ram.l2akt != 1 && ram.gakt == 1)
	{
		ram.l2akt = 1;
	}
	if((PINB & (1<<PINB1)) && ram.l2akt == 1 && ram.gakt == 1)
	{
		ram.l2akt = 0;
		ram.gakt = 0;
	}
}
